//go:build ignore

package main

import (
	"fmt"
	"os"
	"text/template"

	"github.com/grafana/grafana/pkg/services/publicdashboards/commands/generate_datasources"
)

var goTemplate = `
// Code generated by go generate; DO NOT EDIT.

package publicdashboards

var SupportedDatasources = map[string]bool{
{{- range . }}
	"{{ printf "%s" . }}": true,
{{- end }}
}
`

func main() {
	baseUrl := "https://grafana.com"
	slugs, err := generate_datasources.GetCompatibleDatasources(baseUrl)

	myTemplate := template.Must(template.New("").Parse(goTemplate))

	file, err := os.Create("supported_datasources_gen.go")
	if err != nil {
		fmt.Println(err)
	}

	err = myTemplate.Execute(file, slugs)
	if err != nil {
		fmt.Println(err)
	}
}
